@@ -17,8 +17,8 @@ def test_build_simple():
 
 
 def test_build_with_scheme():
-    with pytest.raises(ValueError):
-        URL.build(scheme="http")
+    u = URL.build(scheme="blob", path="path")
+    assert str(u) == "blob:path"
 
 
 def test_build_with_host():
@@ -80,6 +80,23 @@ def test_build_with_all():
     assert str(u) == "http://foo:bar@127.0.0.1:8000/index.html?arg=value1#top"
 
 
+def test_build_with_authority_and_host():
+    with pytest.raises(ValueError):
+        URL.build(authority="host.com", host="example.com")
+
+
+def test_build_with_authority():
+    url = URL.build(scheme="http", authority="ваня:bar@host.com:8000", path="path")
+    assert str(url) == "http://%D0%B2%D0%B0%D0%BD%D1%8F:bar@host.com:8000/path"
+
+
+def test_build_with_authority_without_encoding():
+    url = URL.build(
+        scheme="http", authority="foo:bar@host.com:8000", path="path", encoded=True
+    )
+    assert str(url) == "http://foo:bar@host.com:8000/path"
+
+
 def test_query_str():
     u = URL.build(scheme="http", host="127.0.0.1", path="/", query_string="arg=value1")
     assert str(u) == "http://127.0.0.1/?arg=value1"
